@@ -379,7 +379,8 @@ class HardwareModuleFactory:
         type_ = HardwareModuleConfig.format_type(type_)
         if (
             is_safety_type(type_) and  # only safety modules need this
-            type_ != 'X20cSL8101' and         # (except for X20cSL8101)
+            ((type_ != 'X20cSL8101') and        # (except for X20cSL8101)
+            (type_ != 'X20cSL8100')) and         # (except for X20cSL8100)
             'safemoduleid' not in kwargs
         ):
             safemoduleid = next(self._safemoduleid_counter)
@@ -440,6 +441,31 @@ class HardwareModuleFactory:
         mk0213.add_connection('SL', sl8101, 'SL1')
         return sl8101
 
+    def _new_sl8100(self, name_suffix: str, **kwargs) -> HardwareModule:
+        """Create an instance of the X20cSL8100 hardware module and
+        its dependencies with the specified name suffix and
+        additional settings arguments.
+
+        Args:
+            name_suffix (str): The suffix to be added to the module name and\
+                the names of its dependencies.
+            **kwargs: Additional keyword arguments to be passed to\
+                the module constructor to format module settings.
+
+        Returns:
+            HardwareModule: The created X20cSL8100 hardware module instance.
+        """
+        sl8100 = self._init_module('X20cSL8100', name_suffix, **kwargs)
+        logger.info('Creating dependencies for module "%s".', sl8100.name)
+        tb_type = self._get_required_dependency('X20cSL8100', 'tb')
+        tb = self._init_module(tb_type, name_suffix, **kwargs)
+        mk0213 = self._init_module('X20cMK0213', name_suffix, **kwargs)
+        sl8100.add_dependency(tb)
+        sl8100.add_dependency(mk0213)
+        sl8100.add_connection('SS1', tb, 'SS')
+        mk0213.add_connection('SL', sl8100, 'SL1')
+        return sl8100
+
     def _new_bc0083(self, name_suffix: str, **kwargs) -> HardwareModule:
         """Create an instance of the X20cBC0083 hardware module and
         its dependencies with the specified name suffix and
@@ -550,6 +576,7 @@ class HardwareModuleFactory:
             HardwareModule: The created hardware module.
         """
         special_types = {
+            'x20csl8100': self._new_sl8100,
             'x20csl8101': self._new_sl8101,
             'x20cbc0083': self._new_bc0083,
             'x20cbc8083': self._new_bc8083,
@@ -1018,7 +1045,7 @@ class HardwareIsle(collections.abc.Sequence[HardwareModule]):
     can be traversed in both directions using the `prev_isle` and `next_isle`
     properties.
     """
-    HEAD_TYPES = ['X20cCP1584', 'X20cCP3687X', 'X20cCP1684', 'X20cSL8101', 'X20cBC0083', 'X20cBC8083']
+    HEAD_TYPES = ['X20cCP1584', 'X20cCP3687X', 'X20cCP1684', 'X20cSL8101', 'X20cSL8100', 'X20cBC0083', 'X20cBC8083']
     """The types of modules that can form a hardware isle."""
     POWERLINK_CABLE_LENGTH = 10
     """The default length of the POWERLINK cable."""
@@ -1171,6 +1198,8 @@ class HardwareIsle(collections.abc.Sequence[HardwareModule]):
                 return connect_to, "IF6"
             case "X20cSL8101":
                 return connect_to, "IF1"
+            case "X20cSL8100":
+                return connect_to, "IF1"
             case "X20cBC0083" | "X20cBC8083":
                 return self._get_module_bm(connect_to), "IF1"
             case _:
@@ -1207,7 +1236,7 @@ class HardwareIsle(collections.abc.Sequence[HardwareModule]):
             )
         
     def _connect_to_X20cCP1684(self, to_connect: HardwareIsle) -> None:
-        """Connect the current isle to an isle with a X20cX20cCP1684 head module.
+        """Connect the current isle to an isle with a X20cCP1684 head module.
 
         Args:
             to_connect (HardwareIsle): The isle to connect to.
@@ -1309,9 +1338,10 @@ class HardwareIsle(collections.abc.Sequence[HardwareModule]):
         """
         connectors = {
             'X20cCP1584': self._connect_to_cp1584,
-            'X20cCP3687X': self._connect_to_cp1584,
-            'X20cCP1684': self._connect_to_cp1584,
+            'X20cCP3687X': self._connect_to_X20cCP3687X,
+            'X20cCP1684': self._connect_to_X20cCP1684,
             'X20cSL8101': self._connect_to_sl0101_bc0083,
+            'X20cSL8100': self._connect_to_sl0101_bc0083,
             'X20cBC0083': self._connect_to_sl0101_bc0083,
             'X20cBC8083': self._connect_to_bc8083
             }
